@@ -18,6 +18,7 @@
 #include <libqalculate/qalculate.h>
 
 class QWidget;
+class QWindow;
 class QByteArray;
 class QAction;
 class QFont;
@@ -32,10 +33,13 @@ bool can_display_unicode_string_function(const char *str, void *w);
 
 #define USE_QUOTES(arg, f) (arg && (arg->suggestsQuotes() || arg->type() == ARGUMENT_TYPE_TEXT) && f->id() != FUNCTION_ID_BASE && f->id() != FUNCTION_ID_BIN && f->id() != FUNCTION_ID_OCT && f->id() != FUNCTION_ID_DEC && f->id() != FUNCTION_ID_HEX)
 
+QRect get_screen_geometry(QWidget *w);
+bool try_resize(QWidget *win, int w, int h);
 std::string to_html_escaped(const std::string str);
 std::string unhtmlize(std::string str, bool b_ascii = false);
 QString unhtmlize(QString str, bool b_ascii = false);
 std::string unformat(std::string str, bool restorable = false);
+size_t unformatted_length(const std::string &str);
 std::string uncolorize(std::string str, bool remove_class = true);
 std::string replace_first_minus(const std::string &str);
 QIcon load_icon(const QString &str, QWidget*);
@@ -226,6 +230,7 @@ class QalculateQtSettings : QObject {
 		EvaluationOptions evalops;
 		PrintOptions printops;
 		bool complex_angle_form, dot_question_asked, implicit_question_asked, adaptive_interval_display, tc_set, rpn_mode, chain_mode, caret_as_xor, ignore_locale, do_imaginary_j, fetch_exchange_rates_at_startup, always_on_top, display_expression_status, prefixes_default, rpn_keys, sinc_set;
+		bool automatic_digit_grouping;
 		int simplified_percentage;
 		bool programming_base_changed;
 		int previous_precision;
@@ -236,7 +241,8 @@ class QalculateQtSettings : QObject {
 		int decimal_comma, dual_fraction, dual_approximation, auto_update_exchange_rates, title_type;
 		int completion_delay, expression_status_delay, auto_calculate_delay;
 		int completion_min, completion_min2;
-		int style, palette;
+		QString style;
+		int palette;
 		bool enable_completion, enable_completion2;
 		int enable_tooltips;
 		int color;
